{% extends "lfs/base.html" %}
{% load i18n %}

{% block title %}{% trans "Password reset" %}{% endblock %}
{% block section %}password-reset{% endblock %}
{% block left-slot-wrapper%}{% endblock %}
{% block right-slot-wrapper%}{% endblock %}

{% block breadcrumbs %}
    <ul class="breadcrumbs">
        <li>{% trans 'You are here:' %}</li>
        <li>
            <a href="{% url lfs_shop_view %}">
                {% trans 'Home' %}</a> &gt;
        </li>
        <li>
            {% trans 'Password reset' %}
        </li>
    </ul>
{% endblock %}

{% block wrapper %}
    <h1 class="first-heading">
        {% trans "Password reset" %}
    </h1>
    <p>
        {% trans "Enter your e-mail address below, and we'll e-mail instructions for setting a new one." %}
    </p>
    <form action=""
          method="post">
        {% csrf_token %}
        <div class="field">
            <div class="label">
                {{ form.email.label_tag }}:
            </div>
            <div>
                {{ form.email.errors }}
                {{ form.email }}
            </div>
        </div>
        <input type="submit"
               value="{% trans 'Reset my password' %}" />
    </form>
{% endblock %}
